API Reference
=============

Pipeline Elements
-----------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   datagrabbers
   datareaders
   preprocessing
   markers
   storage

Utilities
---------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   data
   stats
   pipeline
   api
   utils
   testing

Configs
-------

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   configs
